@@ -71,7 +71,10 @@ class ModelConverter:
     def _fix_args(self, call_args: Tuple, node_input_tensors: List[KerasTensor]) -> Tuple[List, List[KerasTensor]]:
         new_tfoplambda_args = list(call_args)
         for i, arg in enumerate(call_args):
-            if isinstance(arg, KerasTensor):
+            if isinstance(arg, dict):
+                new_arg_dict, node_input_tensors = self._fix_kwargs(arg, node_input_tensors)
+                new_tfoplambda_args[i] = new_arg_dict
+            elif isinstance(arg, KerasTensor):
                 try:
                     tensor_index = self._find_tensor_index_by_name(node_input_tensors, arg.name)
                     new_tfoplambda_args[i] = node_input_tensors.pop(tensor_index)
@@ -79,39 +82,44 @@ class ModelConverter:
                     pass
         return new_tfoplambda_args, node_input_tensors
 
-    def _default_call_tf_op_lambda_layer(self,
-                                         converted_layer: TFOpLambda, call_args: Tuple, call_kwargs: Dict,
-                                         node_input_tensors: List[KerasTensor]) -> KerasTensor:
-        new_tfoplambda_args, input_tensors = self._fix_args(call_args, node_input_tensors)
+    def _fix_kwargs(self, call_kwargs, node_input_tensors):
         new_tfoplambda_kwargs = call_kwargs.copy()
         for key, arg in call_kwargs.items():
             if isinstance(arg, KerasTensor):
                 try:
-                    tensor_index = self._find_tensor_index_by_name(input_tensors, arg.name)
-                    new_tfoplambda_kwargs[key] = input_tensors.pop(tensor_index)
+                    tensor_index = self._find_tensor_index_by_name(node_input_tensors, arg.name)
+                    new_tfoplambda_kwargs[key] = node_input_tensors.pop(tensor_index)
                 except (IndexError, ValueError):
                     pass
+        return new_tfoplambda_kwargs, node_input_tensors
+
+    def _default_call_layer_by_args(self,
+                                    converted_layer: Layer, call_args: Tuple, call_kwargs: Dict,
+                                    node_input_tensors: List[KerasTensor]) -> KerasTensor:
+        new_tfoplambda_args, input_tensors = self._fix_args(call_args, node_input_tensors)
+        new_tfoplambda_kwargs, input_tensors = self._fix_kwargs(call_kwargs, node_input_tensors)
+        assert len(input_tensors) == 0
 
         return converted_layer(*new_tfoplambda_args, **new_tfoplambda_kwargs)
 
-    def _call_tf_op_lambda_layer(
-            self, converted_layer: TFOpLambda, node_input_tensors: Union[KerasTensor, List[KerasTensor]],
-            current_layer: TFOpLambda) -> KerasTensor:
+    def _call_layer_by_args(
+            self, converted_layer: Layer, node_input_tensors: Union[KerasTensor, List[KerasTensor]],
+            current_layer: Layer) -> KerasTensor:
 
         call_args = current_layer.inbound_nodes[0].call_args
         call_kwargs = current_layer.inbound_nodes[0].call_kwargs
-        if current_layer.symbol == 'stack':
+        if isinstance(current_layer, TFOpLambda) and current_layer.symbol == 'stack':
             return converted_layer(node_input_tensors, *current_layer.inbound_nodes[0].call_args[2:],
                                    **current_layer.inbound_nodes[0].call_kwargs)
 
         if not isinstance(node_input_tensors, list):
             node_input_tensors = [node_input_tensors]
 
-        if current_layer.symbol == 'concat':
+        if isinstance(current_layer, TFOpLambda) and current_layer.symbol == 'concat':
             # default call expects [list_of_values] while for concat it is [[list_of_values]]
             call_args = [self._fix_args(call_args[0], node_input_tensors)[0]]
 
-        return self._default_call_tf_op_lambda_layer(converted_layer, call_args, call_kwargs, node_input_tensors)
+        return self._default_call_layer_by_args(converted_layer, call_args, call_kwargs, node_input_tensors)
 
     def _convert_tensor(self, tensor: tf.Tensor) -> tf.Tensor:
         tensor_id = id(tensor)
@@ -152,7 +160,7 @@ class ModelConverter:
 
         if converted_layer_built:
             if isinstance(converted_layer, TFOpLambda):
-                converted_tensor = self._call_tf_op_lambda_layer(converted_layer, node_input_tensors, current_layer)
+                converted_tensor = self._call_layer_by_args(converted_layer, node_input_tensors, current_layer)
             else:
                 converted_tensor = converted_layer(node_input_tensors)
         elif isinstance(current_layer, MultiHeadAttention):
@@ -170,6 +178,10 @@ class ModelConverter:
             permute_after = tf.keras.layers.Permute(perm_values)(tensor)
             self._tensor_name_to_original_tensor_name[permute_after.name] = tensor.name
             converted_tensor = permute_after
+        elif type(converted_layer) in self.custom_layers.values():
+            converted_tensor = self._call_layer_by_args(converted_layer, node_input_tensors, current_layer)
+            weights = current_layer.get_weights()
+            converted_layer.set_weights(weights)
         else:
             weights = current_layer.get_weights()
             converted_tensor = converted_layer(node_input_tensors)
@@ -209,4 +221,3 @@ class ModelConverter:
         self._tensor_cache: Dict[int, tf.Tensor] = {}
         self._model_input_tensors: List[tf.Tensor] = []
         self._tensor_name_to_original_tensor_name: Dict[str, str] = {}
-
